library(prabclus)
example(autoconst)
example(cluspop.nb)
example(con.comp)
example(con.regmat)
example(distratio)
example(homogen.test)
example(incmatrix)
example(jaccard)
example(kulczynski)
example(lcomponent)
example(NNclean)
example(nbtest)
example(nn)
example(pop.sim)
example(prabclust)
example(prabtest)
example(randpop.nb)
# example(summary.prabtest)
example(geco)
example(geo2neighbor)
example(hprabclust)
example(piecewiselin)
example(qkulczynski)
example(regpop.sar)
# regpop.sar(x, p.nb=0.046)
example(toprab)
example(prab.sarestimate)
# prab.sarestimate(x)
example(specgroups)
# example(abundtest)
set.seed(1234)
# This is done in example(specgroups):
# x <- prabinit(prabmatrix=siskiyou, neighborhood=siskiyou.nb,
#              distance="logkulczynski")
# a1 <- abundtest(x, times=3, p.nb=0.0465)
# a2 <- abundtest(x, times=3, p.nb=0.0465, teststat="groups",
#                 groupvector=siskiyou.groups)
# summary(a1)
# summary(a2)
# build.nblist(x)
